import type { Ability } from "@proscenium/playbill";
import { HTML } from "./base/html";

interface AbilityCardProps {
  ability: Ability;
}

export function AbilityCard({ ability }: AbilityCardProps) {
  const costs: React.ReactNode[] = [];

  if (ability.ap > 0) {
    costs.push(<li key="ap" className="ability-cost-ap">{ability.ap} AP</li>);
  }

  if (ability.hp > 0) {
    costs.push(<li key="hp" className="ability-cost-hp">{ability.hp} HP</li>);
  }

  if (ability.ep > 0) {
    costs.push(<li key="ep" className="ability-cost-ep">{ability.ep} EP</li>);
  }

  const costList =
    costs.length > 0
      ? <ul className="ability-costs">{costs}</ul>
      : "";

  const classList = `ability ability-${ability.type}`;

  return <div className={classList} data-component-id={ability.id}>
    <div className="ability-header">
      <h4>{ability.name}</h4>
      <span className="ability-type">{ability.type}</span>
      <span className="ability-cost-xp">{ability.xp} XP</span>
      {costList}
    </div>
    <HTML className="ability-content" html={ability.description} />
  </div>
}
